import { HttpClient as HC } from "./lib/http/http-client";
import { BackendProxy as BP } from "./lib/http/backend-proxy";
import { BuildSessionData as BSD, IPullRequestParams as IPP, IPRConfigRequest as IPR, CreateBuildSessionIdResponse as CBIDResponse, HttpClientConfigData as HCCD, GetVersionRequest as GVR, IHttpClient as IHC, ITestsRecommendationResponse as ITRR, RecommendedTestReason as RTR, IRecommendedTestBase as IRTB, IRecommendedTest as IRT, RecommendationSetStatus as RSS } from "./lib/http/contracts";
import { MessagesFormatter as MF } from "./lib/messages-formatter";
import { SlEnvVars as SEV } from "./lib/constants/sl-env-vars";
import { FootprintsProcess as FPP } from "./lib/footprints-process";
import { IstanbulToFootprints as ITF } from "./lib/footprints-process/istanbul-to-footprints";
import { Watchdog as WD } from "./lib/watchdog";
import { WatchdogOptions as WDO } from "./lib/watchdog";
import { FootprintsServiceProxy as FPRX } from "./lib/footprints-process/footprints-service-proxy";
import { EnvironmentDataService as EDS, IEnvironmentDataService as IEDS } from "./lib/environment-data-service";
import { AgentConfig as CFG } from "./lib/config";
import { ConfigLoader as CLD } from "./lib/config-loader";
import { IExtendedIstanbulMetrics as EIM } from "./lib/footprints-process/istanbul-to-footprints-contract";
import { AgentDataService as ADS } from "./lib/agent-data-service";
import { IFootprintsFile as IPF, IFootprintsHandler as IFPH } from "./lib/contracts";
import { ValidationUtils as VU } from "./lib/utils/validation-utils";
import { IgnoredFilesHandler as IFH } from "./lib/ignored-files-handler";
import { ProductionFootprintsHandler as PFPH } from "./lib/footprints-process/production-footprints-handler";
import { StartExecutionRequest as SER, EndExecutionRequest as EER, UploadReportRequest as URR, AgentData as AD, UploadReportsBody as URB } from "./lib/http/contracts";
import { UniqueIdConverter as UIDC } from "./lib/coverage-elements/unique-id-converter";
import { ShortNameToFileMapper as SNTF } from "./lib/short-name-to-file-mapper";
import { IQueue as IQ, Queue as Q } from "./lib/queue";
import { EventsProcess as EP } from "./lib/events-process";
import { IWatchdog as IWD } from "./lib/watchdog";
import { EventsCreator as EC } from "./lib/events-process/events-creator";
import { IEvent as IEVT, ITestStartEvent as ITS, ITestEndEvent as ITE, EventTypes as ET, TestSelectionStatus as TSS } from "./lib/events-process/events-contracts";
import { SourceMapReader as SMR } from "./lib/source-map-reader";
import { SourceMapHandler as SMH } from "./lib/source-map-handler";
import { AgentEventsController as AEC } from "./lib/agent-events/agent-events-controller";
import { FilesUtils as FU } from "./lib/utils/files-utils";
import { AgentType as AT, Technology as TEC, AgentEventCode as AECD, IToolInfo as ITI } from "./lib/agent-events/agent-events-conracts";
import { MockServerProxy as MSP } from "./lib/utils/test-utils/mock-server-utils/mock-server-proxy";
import { getSystemDateValueOf as GSD } from "./lib/system-date";
export declare namespace SlJsInfra {
    type Watchdog = WD;
    const Watchdog: typeof WD;
    type HttpClient = HC;
    const HttpClient: typeof HC;
    type BackendProxy = BP;
    const BackendProxy: typeof BP;
    type AgentConfig = CFG;
    const AgentConfig: typeof CFG;
    type ConfigLoader = CLD;
    const ConfigLoader: typeof CLD;
    type MessageFormatter = MF;
    const MessageFormatter: typeof MF;
    type SlEnvVars = SEV;
    const SlEnvVars: typeof SEV;
    type FootprintsProcess = FPP;
    const FootprintsProcess: typeof FPP;
    type FootprintsProxy = FPRX;
    const FootprintsProxy: typeof FPRX;
    type ProductionFootprintsHandler = PFPH;
    const ProductionFootprintsHandler: typeof PFPH;
    type IstanbulToFootprints = ITF;
    const IstanbulToFootprints: typeof ITF;
    type EnvironmentDataService = EDS;
    const EnvironmentDataService: typeof EDS;
    type AgentDataService = ADS;
    const AgentDataService: typeof ADS;
    type IgnoredFilesHandler = IFH;
    const IgnoredFilesHandler: typeof IFH;
    type UniqueIdConverter = UIDC;
    const UniqueIdConverter: typeof UIDC;
    type ShortNameToFileMapper = SNTF;
    const ShortNameToFileMapper: typeof SNTF;
    type EventsProcess = EP;
    const EventsProcess: typeof EP;
    type EventsCreator = EC;
    const EventsCreator: typeof EC;
    type SourceMapReader = SMR;
    const SourceMapReader: typeof SMR;
    type AgentEventsController = AEC;
    const AgentEventsController: typeof AEC;
    type Queue<T> = Q<T>;
    const Queue: typeof Q;
    type Agent = SMH;
    const SourceMapHandler: typeof SMH;
    const getSystemDateValueOf: typeof GSD;
    namespace Utils {
        type ValidationUtils = VU;
        const ValidationUtils: typeof VU;
        type FileUtils = FU;
        const FileUtils: typeof FU;
    }
    namespace TestUtils {
        type MockServerProxy = MSP;
        const MockServerProxy: typeof MSP;
    }
    namespace Entities {
        type BuildSessionData = BSD;
        type CreateBuildSessionIdResponse = CBIDResponse;
        const CreateBuildSessionIdResponse: typeof CBIDResponse;
        type HttpClientConfigData = HCCD;
        const HttpClientConfigData: typeof HCCD;
        type GetVersionRequest = GVR;
        const GetVersionRequest: typeof GVR;
        type WatchdogOptions = WDO;
        const WatchdogOptions: typeof WDO;
        type IExtendedIstanbulMetrics = EIM;
        const IExtendedIstanbulMetrics: typeof EIM;
        type IFootprintsFile = IPF;
        type IFootprintsHandler = IFPH;
        type StartExecutionRequest = SER;
        const StartExecutionRequest: typeof SER;
        type EndExecutionRequest = EER;
        const EndExecutionRequest: typeof EER;
        type UploadReportRequest = URR;
        const UploadReportRequest: typeof URR;
        type AgentData = AD;
        const AgentData: typeof AD;
        type UploadReportsBody = URB;
        const UploadReportsBody: typeof URB;
        type IHttpClient = IHC;
        type IEnvironmentDataService = IEDS;
        type IQueue = IQ<any>;
        type IWatchdog = IWD;
        type IEvent = IEVT;
        type ITestStartEvent = ITS;
        type ITestEndEvent = ITE;
        type EventTypes = ET;
        const EventTypes: typeof ET;
        type AgentType = AT;
        const AgentType: typeof AT;
        type Technology = TEC;
        const Technology: typeof TEC;
        type AgentEventCode = AECD;
        const AgentEventCode: typeof AECD;
        type IToolInfo = ITI;
        type IPRConfigRequest = IPR;
        type IPullRequestParams = IPP;
        type IRecommendedTest = IRT;
        type IRecommendedTestBase = IRTB;
        type RecommendedTestReason = RTR;
        type ITestsRecommendationResponse = ITRR;
        type RecommendationSetStatus = RSS;
        const RecommendationSetStatus: typeof RSS;
        type TestSelectionStatus = TSS;
        const TestSelectionStatus: typeof TSS;
    }
}
