"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var agent_events_conracts_1 = require("./agent-events-conracts");
var files_utils_1 = require("../utils/files-utils");
var fs_1 = require("fs");
var SEALIGHTS_ENV_VAR_PREFIX = "SL_";
var AgentInstanceInfoBuilder = /** @class */ (function () {
    function AgentInstanceInfoBuilder(gentEventsController) {
        this.agentConfig = gentEventsController.agentConfig;
        this.agentId = gentEventsController.agentId;
        this.agentType = gentEventsController.type;
        this.tags = gentEventsController.resolveTags();
        this.tools = gentEventsController.tools;
        this.sendsPing = gentEventsController.sendsPing;
        this.logger = gentEventsController.logger;
        this.technology = gentEventsController.technology;
        this.info = {};
    }
    AgentInstanceInfoBuilder.prototype.fillData = function () {
        this.info.agentType = this.agentType;
        this.info.tags = this.tags;
        this.info.tools = this.tools;
        this.info.agentVersion = this.resolveAgentVersion();
        this.info.technology = this.technology;
        this.info.sendsPing = this.sendsPing;
        this.fillFromAgentConfig();
        this.fillFromProcessObject();
    };
    AgentInstanceInfoBuilder.prototype.build = function () {
        this.fillData();
        return this.info;
    };
    AgentInstanceInfoBuilder.prototype.fillFromAgentConfig = function () {
        this.info.buildSessionId = this.agentConfig.buildSessionId.value;
        this.info.labId = this.agentConfig.labId.value;
        this.info.agentConfig = this.agentConfig.toJsonObject();
    };
    ;
    AgentInstanceInfoBuilder.prototype.fillFromProcessObject = function () {
        this.info.processId = process.pid;
        this.info.processArch = process.arch;
        this.info.argv = process.argv;
        this.info.cwd = process.cwd();
        this.info.envVars = this.extractSealightsEnvVars();
    };
    ;
    AgentInstanceInfoBuilder.prototype.extractSealightsEnvVars = function () {
        var slEnvVars = {};
        Object.keys(process.env).forEach(function (key) {
            if (key.indexOf(SEALIGHTS_ENV_VAR_PREFIX) === 0) {
                slEnvVars[key] = process.env[key];
            }
        });
        return slEnvVars;
    };
    AgentInstanceInfoBuilder.prototype.resolveAgentVersion = function () {
        if (this.technology === agent_events_conracts_1.Technology.BROWSER) {
            return this.resolveAgentVersionForBrowserAgent();
        }
        var packageJsonFilePath = files_utils_1.FilesUtils.findFileUp("package.json", __dirname);
        if (packageJsonFilePath) {
            try {
                var packageJson = fs_1.readFileSync(packageJsonFilePath).toString();
                var parsed = JSON.parse(packageJson);
                return parsed.version;
            }
            catch (e) {
                this.logger.warn("Failed to resolve agent version, Error: '" + e);
                return null;
            }
        }
        return null;
    };
    AgentInstanceInfoBuilder.prototype.resolveAgentVersionForBrowserAgent = function () {
        return (window && window[AgentInstanceInfoBuilder.SEALIGHTS_WINDOW_OBJECT] && window[AgentInstanceInfoBuilder.SEALIGHTS_WINDOW_OBJECT].agentVersion) || AgentInstanceInfoBuilder.DEFAULT_BROWSER_AGENT_VERSION;
    };
    AgentInstanceInfoBuilder.DEFAULT_BROWSER_AGENT_VERSION = "1.0.0";
    AgentInstanceInfoBuilder.SEALIGHTS_WINDOW_OBJECT = "$Sealights";
    return AgentInstanceInfoBuilder;
}());
exports.AgentInstanceInfoBuilder = AgentInstanceInfoBuilder;
//# sourceMappingURL=agent-instance-info-builder.js.map